@@ -2,7 +2,7 @@ package PPM;
 require 5.004;
 require Exporter;
 use vars qw( $VERSION );
-$VERSION = '0.01_02';
+$VERSION = '0.01_03';
 
 @ISA = qw(Exporter);
 @EXPORT = qw(PPMdat PPMERR InstalledPackageProperties ListOfRepositories
@@ -411,11 +411,11 @@ sub InstallPackage
     my $INST_HTMLHELPDIR = File::Spec->catdir(File::Spec->curdir,'blib','htmlhelp');
 
     my $inst_script = $Config{installscript};
-    my $inst_man1dir = $Config{installman1dir};
-    my $inst_man3dir = $Config{installman3dir};
+    my $inst_man1dir = $Config{installman1dir} || q{};
+    my $inst_man3dir = $Config{installman3dir} || q{};
     my $inst_bin = $Config{installbin};
-    my $inst_htmldir = $Config{installhtmldir};
-    my $inst_htmlhelpdir = $Config{installhtmlhelpdir};
+    my $inst_htmldir = $Config{installhtmldir} || q{};
+    my $inst_htmlhelpdir = $Config{installhtmlhelpdir} || q{};
     my $inst_lib = $Config{installsitelib};
 
     if (defined $root && $root !~ /^\Q$inst_root\E$/i) {
@@ -435,12 +435,17 @@ sub InstallPackage
         &Trace("Calling ExtUtils::Install::install") if $options{'TRACE'} > 1;
         eval {
             ExtUtils::Install::install({
-            "read" => $packlist, "write" => $packlist,
-            $INST_LIB => $inst_lib, $INST_ARCHLIB => $inst_archlib,
-            $INST_BIN => $inst_bin, $INST_SCRIPT => $inst_script,
-            $INST_MAN1DIR => $inst_man1dir, $INST_MAN3DIR => $inst_man3dir,
-            $INST_HTMLDIR => $inst_htmldir,
-            $INST_HTMLHELPDIR => $inst_htmlhelpdir},0,0,0);
+            "read" => $packlist, 
+			"write" => $packlist,
+            $INST_LIB => $inst_lib, 
+			$INST_ARCHLIB => $inst_archlib,
+            $INST_BIN => $inst_bin, 
+			$INST_SCRIPT => $inst_script,
+            ($inst_man1dir ne q{}) ? ($INST_MAN1DIR => $inst_man1dir) : (),  
+            ($inst_man3dir ne q{}) ? ($INST_MAN3DIR => $inst_man3dir) : (),  
+            ($inst_htmldir ne q{}) ? ($INST_HTMLDIR => $inst_htmldir) : (),  
+            ($inst_htmlhelpdir ne q{}) ? ($INST_HTMLHELPDIR => $inst_htmlhelpdir) : (),  
+			},0,0,0);
         };
         # install might have croaked in another directory
         chdir($cwd);
